from typing import AsyncIterator, Iterable

from tdm.abstract.datamodel import AbstractDomainType
from tdm.datamodel.domain import Domain

from talisman_api import APISchema, version
from ._abstract import TalismanDomainAPIImpl


@version('0.14.10')
class _ImplV10(TalismanDomainAPIImpl):
    async def all_property_types(self) -> AsyncIterator[dict]:
        async for i in self._client(APISchema.KB_UTILS).get_all_items('paginationConceptPropertyTypeIE'):
            yield i

        async for i in self._client(APISchema.KB_UTILS).get_all_items('paginationRelationPropertyTypeIE'):
            yield i

    async def platform_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    async def account_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    async def story_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    def generate_types(self, domain: Domain) -> Iterable[AbstractDomainType]:
        from tie_domain.domain._synthetic import generate_types
        return generate_types(domain)



from typing import AsyncIterator, Iterable

from tdm.abstract.datamodel import AbstractDomainType
from tdm.datamodel.domain import Domain

from talisman_api import version
from ._abstract import TalismanDomainAPIImpl


@version('0.16.4')
class _ImplV164(TalismanDomainAPIImpl):
    async def platform_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    async def account_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    async def story_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}

    def generate_types(self, domain: Domain) -> Iterable[AbstractDomainType]:
        from tie_domain.domain._synthetic import generate_types
        return generate_types(domain)



from typing import AsyncIterator

from talisman_api import version
from ._abstract import TalismanDomainAPIImpl


@version('0.17.0')
class _ImplV170(TalismanDomainAPIImpl):
    async def story_types(self) -> AsyncIterator[dict]:
        if False:
            yield {}



__all__ = [
    '_ImplV173', '_ImplV170', '_ImplV164', '_ImplV10', '_ImplV8'
]

from ._0_14_10 import _ImplV10
from ._0_14_8 import _ImplV8
from ._0_16_4 import _ImplV164
from ._0_17_0 import _ImplV170
from ._0_17_3 import _ImplV173



from typing import Iterable

from tdm.abstract.datamodel import AbstractDomainType
from tdm.datamodel.domain import ConceptType, Domain

from tp_interfaces.domain.model.types import IdentifyingPropertyType, PropertyType
from ._common import STR_VALUE

# CONCEPTS
RUBRIC = ConceptType('Рубрика', id='rubric')

# PROPERTIES
RUBRIC_ID = IdentifyingPropertyType("Название", RUBRIC, STR_VALUE, id='rubric_id')
RUBRICATOR_ID = PropertyType("Рубрикатор", RUBRIC, STR_VALUE, id='rubricator_id')


def generate_types(domain: Domain) -> Iterable[AbstractDomainType]:
    return RUBRIC, RUBRIC_ID, RUBRICATOR_ID, STR_VALUE
